@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	$Id: mhtxttsv.pl,v 2.4 2001/08/25 20:01:01 ehood Exp $
+##	$Id: mhtxttsv.pl,v 2.5 2003/01/19 01:35:59 ehood Exp $
 ##  Author:
 ##      Earl Hood       mhonarc@mhonarc.org
 ##  Description:
@@ -37,18 +37,18 @@ package m2h_text_tsv;
 ##	Text/tab-separated-values filter for mhonarc.
 ##
 sub filter {
-    my($fields, $data, $isdecode, $args) = @_;
-    my($field, $line, $ret);
-    local($_);
+    my ($fields, $data, $isdecode, $args) = @_;
+    my ($field, $line, $ret);
+    local ($_);
 
     $$data =~ s/^\s+//;
-    $ret  = "<table border=1>\n";
+    $ret = "<table border=1>\n";
     foreach $line (split(/\r?\n/, $$data)) {
-	$ret .= "<tr>";
-	foreach $field (split(/\t/, $line)) {
-	    $ret .= "<td>$field</td>";
-	}
-	$ret .= "</tr>\n";
+        $ret .= "<tr>";
+        foreach $field (split(/\t/, $line)) {
+            $ret .= '<td>' . mhonarc::htmlize($field) . '</td>';
+        }
+        $ret .= "</tr>\n";
     }
     $ret .= "</table>\n";
     ($ret);
